@@ -239,7 +239,7 @@ void get_hash_value(parsertype p, void *elem, unsigned char *hash)
 	ascii_to_hash(hash, hash_ascii);
 }
 
-bool set_find_path(const char **nodes, const char *newpath, char ***tmp)
+bool set_find_path(const char **nodes, const char *newpath)
 {
 	char **paths;
 	unsigned int count;
@@ -329,7 +329,7 @@ bool set_find_path(const char **nodes, const char *newpath, char ***tmp)
 	}
 
 	free(ref);
-	*tmp = paths;
+	free(paths);
 
 	return true;
 }
