@@ -16,6 +16,7 @@
 #include <sys/sysmacros.h>
 #endif
 #include <sys/types.h>
+#include <limits.h>
 
 #include "lua.h"
 #include "lauxlib.h"
@@ -929,6 +930,11 @@ static int l_get_selection(lua_State *L) {
 	return 2;
 }
 
+static int l_is_dry_run(lua_State *L) {
+	bool dryrun = is_dryrun_install();
+	lua_pushboolean(L, dryrun);
+	return 1;
+}
 
 static int l_get_tmpdir(lua_State *L)
 {
@@ -1001,12 +1007,9 @@ static void lua_push_enum(lua_State *L, const char *name, int value)
 
 int lua_get_swupdate_version(lua_State *L)
 {
-	unsigned int version = 0, patchlevel = 0;
-	/* Deliberately ignore sublevel and extraversion. */
-	if (sscanf(SWU_VER, "%u.%u.%*s", &version, &patchlevel) != 2) {
-		version = 0;
-		patchlevel = 0;
-	}
+	const unsigned int version = VERSION;
+	const unsigned int patchlevel = VERSION_PATCHLEVEL;
+
 	lua_newtable (L);
 	lua_pushnumber(L, 1);
 	lua_pushnumber(L, version);
@@ -1214,6 +1217,7 @@ static const luaL_Reg l_swupdate[] = {
         { "getversion", lua_get_swupdate_version },
         { "progress", lua_notify_progress },
         { "emmcbootpart", l_get_emmc_bootpart },
+	{ "is_dryrun", l_is_dry_run },
         { NULL, NULL }
 };
 
