@@ -4,6 +4,7 @@
 
 #include <ctype.h>
 #include <errno.h>
+#include <mbedtls/version.h>
 #include <stdlib.h>
 
 #include "sslapi.h"
@@ -87,7 +88,11 @@ int swupdate_HASH_final(struct swupdate_digest *dgst, unsigned char *md_value,
 		return -EINVAL;
 	}
 	if (md_len) {
+#if MBEDTLS_VERSION_NUMBER >= 0x03020000
+		*md_len = mbedtls_md_get_size(mbedtls_md_info_from_ctx(&dgst->mbedtls_md_context));
+#else
 		*md_len = mbedtls_md_get_size(dgst->mbedtls_md_context.md_info);
+#endif
 	}
 	return 1;
 
