@@ -15,7 +15,9 @@
 #include <pthread.h>
 #include <signal.h>
 #include <libgen.h>
+#ifdef CONFIG_MTD
 #include <mtd/mtd-user.h>
+#endif
 #include <ftw.h>
 #ifdef __FreeBSD__
 #include <sys/disk.h>
@@ -24,6 +26,18 @@
 #else
 #include <linux/fs.h>
 #endif
+/*
+ * Though the glibc-specific flag `FTW_ACTIONRETVAL` wasn't passed to `nftw()`,
+ * the specific return codes are used nonetheless. As they happen to match
+ * the defaults, just define them for musl and non-Linux systems. 
+ */
+#ifndef FTW_CONTINUE
+#define FTW_CONTINUE  0
+#endif
+#ifndef FTW_STOP
+#define FTW_STOP 1
+#endif
+#include <unistd.h>
 
 #include <pctl.h>
 #include "swupdate_image.h"
@@ -47,7 +61,9 @@ static int copy_single_file(const char *path, ssize_t size, struct img_type *img
 {
 	int fdout, fdin, ret;
 	struct stat statbuf;
-	struct mtd_info_user	mtdinfo;
+#ifdef CONFIG_MTD
+	struct mtd_info_user mtdinfo;
+#endif
 	struct chain_handler_data priv;
 	uint32_t checksum;
 	int pipes[2];
@@ -80,7 +96,9 @@ static int copy_single_file(const char *path, ssize_t size, struct img_type *img
 		else if (S_ISBLK(statbuf.st_mode) && (ioctl(fdin, BLKGETSIZE64, &size) < 0)) {
 			ERROR("Cannot get size of Block Device %s", path);
 			size = -1;
-		} else if (S_ISCHR(statbuf.st_mode)) {
+		} 
+#ifdef CONFIG_MTD
+		else if (S_ISCHR(statbuf.st_mode)) {
 			/* it is maybe a MTD device, just try */
 			ret = ioctl(fdin, MEMGETINFO, &mtdinfo);
 			if (!ret) {
@@ -89,6 +107,10 @@ static int copy_single_file(const char *path, ssize_t size, struct img_type *img
 				size = -1;
 			}
 		}
+#endif
+		else {
+			size = -1;
+		}
 	}
 
 	if (size < 0) {
