@@ -2,7 +2,7 @@
  * Author: Christian Storm
  * Copyright (C) 2018, Siemens AG
  *
- * SPDX-License-Identifier:     GPL-2.0-only
+ * SPDX-License-Identifier:     LGPL-2.1-or-later
  */
 
 #pragma once
@@ -45,5 +45,13 @@
 /*
  * The BSDs don't define this while Linux does.
  */
-#define __u64 uint64_t
+#include <sys/types.h>
+typedef int8_t   __s8;
+typedef uint8_t  __u8;
+typedef int16_t  __s16;
+typedef uint16_t __u16;
+typedef int32_t  __s32;
+typedef uint32_t __u32;
+typedef int64_t  __s64;
+typedef uint64_t __u64;
 #endif
