@@ -38,13 +38,14 @@ extern char* SOCKET_PROGRESS_PATH;
  * - changes in major mean an incompatibility and clients do not work anymore
  */
 
-#define PROGRESS_API_MAJOR	1
+#define PROGRESS_API_MAJOR	2
 #define PROGRESS_API_MINOR	0
 #define PROGRESS_API_PATCH	0
 
 #define PROGRESS_API_VERSION 	((PROGRESS_API_MAJOR & 0xFFFF) << 16 | \
 				(PROGRESS_API_MINOR & 0xFF) << 8 | \
 				(PROGRESS_API_PATCH & 0xFF))
+
 /*
  * Message sent via progress socket.
  * Data is sent in LE if required.
@@ -64,6 +65,12 @@ struct progress_msg {
 	char		info[PRINFOSIZE]; /* additional information about install */
 };
 
+#define PROGRESS_CONNECT_ACK_MAGIC "ACK"
+struct progress_connect_ack {
+	unsigned int apiversion; /* API Version for compatibility check */
+	char magic[4];           /* null-terminated string */
+};
+
 char *get_prog_socket(void);
 
 /* Standard function to connect to progress interface */
@@ -75,8 +82,9 @@ int progress_ipc_connect(bool reconnect);
  */
 int progress_ipc_connect_with_path(const char *socketpath, bool reconnect);
 
-/* Retrieve messages from progress interface (it blocks) */
+/* Retrieve messages from progress interface (blocking and non-blocking) */
 int progress_ipc_receive(int *connfd, struct progress_msg *msg);
+int progress_ipc_receive_nb(int *connfd, struct progress_msg *msg);
 
 #ifdef __cplusplus
 }   // extern "C"
