@@ -6,8 +6,7 @@
  * SPDX-License-Identifier: MIT
  */
 
-#ifndef __SEMVER_H
-#define __SEMVER_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -102,5 +101,3 @@ semver_clean (char *s);
 #ifdef __cplusplus
 }
 #endif
-
-#endif
