@@ -132,7 +132,6 @@ static int parser_follow_link(parsertype p, void *cfg, void *elem,
 {
 	const char *ref;
 	void *link;
-	char **tmp = NULL;	/* to store temporary link path */
 	const char **linknodes;
 	int result = 0;
 
@@ -144,7 +143,7 @@ static int parser_follow_link(parsertype p, void *cfg, void *elem,
 	for (int j = 0; j < count_string_array(nodes); j++) {
 		linknodes[j] = nodes[j];
 	}
-	if (!set_find_path(linknodes, ref, &tmp)) {
+	if (!set_find_path(linknodes, ref)) {
 		free(linknodes);
 		return -1;
 	}
@@ -153,7 +152,6 @@ static int parser_follow_link(parsertype p, void *cfg, void *elem,
 	if (link) {
 		result = fn(p, cfg, link, linknodes, swcfg, L);
 	}
-	free_string_array(tmp);
 	free(linknodes);
 	return result;
 }
