@@ -598,22 +598,29 @@ setmetatable(M.job.status, {
     end,
 })
 
---- Update job status JSON schema from its OpenAPI (Swagger) definition.
+--- Update job status JSON schema from its OpenAPI specification.
 --
---- @param  swagger  table  Swagger definition
---- @return boolean         # `true` if swagger was parsed, `false` otherwise
-function M.job.status:update_json_schema(swagger)
-    if type(swagger) ~= "table" then
+--- @param  oapispec  table  OpenAPI v2 (Swagger) or OpenAPI v3 specification
+--- @return boolean          # `true` if specification was processed, `false` otherwise
+function M.job.status:update_json_schema(oapispec)
+    if type(oapispec) ~= "table" then
         return false
     end
-    local spec = (((swagger or {}).definitions or {}).JobStatus or {}).properties or {}
+    -- Try OpenAPI v3 specification first...
+    local spec = ((((oapispec or {}).components or {}).schemas or {}).JobStatus or {}).properties or {}
+    if M.utils.table.is_empty(spec) then
+        -- ... and fall-back to OpenAPI v2 (Swagger)
+        spec = (((oapispec or {}).definitions or {}).JobStatus or {}).properties or {}
+    end    
     if M.utils.table.is_empty(spec) then
         return false
     end
     for k, v in pairs(spec) do
         if self.json_schema[k] then
-            local max = v.maxLength or v.maximum
-            self.json_schema[k].max = max and tonumber(max) or nil
+            local min = v.minLength or v.minimum or self.json_schema[k].min or 0
+            self.json_schema[k].min = tonumber(min)
+            local max = v.maxLength or v.maximum or self.json_schema[k].max or math.huge
+            self.json_schema[k].max = tonumber(max)
         end
     end
     return true
@@ -624,6 +631,7 @@ end
 --- @param  status  job.status  Job status instance to normalize
 --- @return job.status          # Normalized `job.status` instance
 function M.job.status.normalize(status)
+    status = status or {}
     status.state = status.state or "0xDEAD57A7E"
     status.clientId = M.device.id
     status.progress = status.progress or 0
@@ -1315,8 +1323,8 @@ M.job.workflow.dispatch:set(
                     msg,
                     prepare_logs(
                         updatelog,
-                        job.status.json_schema.context.max,
-                        job.status.json_schema.context.delimiter
+                        job.status.json_schema.context.max or math.huge,
+                        job.status.json_schema.context.delimiter or ", "
                     )
                 )
             end
@@ -1496,8 +1504,8 @@ M.job.workflow.dispatch:set(
                     msg,
                     prepare_logs(
                         updatelog,
-                        job.status.json_schema.context.max,
-                        job.status.json_schema.context.delimiter
+                        job.status.json_schema.context.max or math.huge,
+                        job.status.json_schema.context.delimiter or ", "
                     )
                 )
             end
@@ -1796,7 +1804,7 @@ M.job.workflow.dispatch:set(
 --- @field version string            Device client version information, sent to server in HTTP Header
 --- @field reset   function(device)  Reset `device` Table
 M.device = {
-    version = ("SWUpdate %s.%s"):format(table.unpack(suricatta.getversion() or { 2023, 5 })),
+    version = ("SWUpdate %04u.%02u"):format(table.unpack(suricatta.getversion() or { 2025, 5 })),
     reset = function(self)
         self.id = nil
         self.pstate = nil
@@ -1816,14 +1824,20 @@ M.channel = setmetatable({}, {
     end,
 })
 
+--- @class server.value
+--- @field default  any | nil
+--- @field current  any | nil
+
 --- Server information.
 --
 --- @class server
 --- @field polldelay  number            Delay between two wfx poll operations in seconds
+--- @field yieldtime  server.value      Time to next polling after yielding to wfx in seconds
 --- @field reset      function(server)  Reset `server` Table
 M.server = {
     reset = function(self)
         self.polldelay = nil
+        self.yieldtime = { current = nil, default = 10 }
     end,
 }
 
@@ -1918,6 +1932,8 @@ function M.suricatta_funcs.has_pending_action()
         return query_wfx(("%s/jobs/%s"):format(M.channel.main.options.url, M.job.id))
     end
 
+    M.server.yieldtime.current = nil
+
     -- ────┤ Handle & Dispatch ├──────────────────────────────────────
     local response, j = get_current_job()
     if not response then
@@ -1939,6 +1955,7 @@ function M.suricatta_funcs.has_pending_action()
         return suricatta.status.EAGAIN
     end
 
+    M.server.yieldtime.current = M.server.yieldtime.default
     suricatta.notify.info("Processing job ID %s in state %s ...", M.job.id, M.job.status.state)
     _ = M.job.workflow:advance(M.job)
     suricatta.notify.info("Yielding to wfx.")
@@ -1964,6 +1981,7 @@ end, suricatta.server.INSTALL_UPDATE)
 --- @param  defaults  suricatta.channel.options|table  Default options
 --- @return suricatta.status                           # Suricatta return code
 function M.suricatta_funcs.print_help(defaults)
+    M.server:reset()
     defaults = defaults or {}
     local stdout = io.output()
     stdout:write("\t  -u, --url <URL>          * Base URL to the wfx server, e.g.,http://localhost:8080/api/wfx/v1\n")
@@ -1974,6 +1992,11 @@ function M.suricatta_funcs.print_help(defaults)
             tostring(defaults.polldelay or "?")
         )
     )
+    stdout:write(
+        ("\t  -t, --yieldtime <int>      Polling wait time in between two workflow steps (default: %s sec)\n"):format(
+            tostring(M.server.yieldtime.default or "?")
+        )
+    )
     stdout:write(
         ("\t  -r, --retry <int>          Retry count prior to failing (default: %s)\n"):format(
             tostring(defaults.retries or "?")
@@ -2000,6 +2023,7 @@ suricatta.server.register(M.suricatta_funcs.print_help, suricatta.server.PRINT_H
 --- @param  fconfig   {[string]: any}  SWUpdate configuration file's `[suricatta]` section as Lua Table ∪ { polldelay = CHANNEL_DEFAULT_POLLING_INTERVAL}
 --- @return suricatta.status           # Suricatta return code
 function M.suricatta_funcs.server_start(defaults, argv, fconfig)
+    M.server:reset()
     -- Use defaults,
     -- ... shadowed by configuration file values,
     -- ... shadowed by command line arguments.
@@ -2010,6 +2034,7 @@ function M.suricatta_funcs.server_start(defaults, argv, fconfig)
         { "id", M.utils.GETOPT_ARG.REQUIRED, "i" },
         { "proxy", M.utils.GETOPT_ARG.REQUIRED, "y" },
         { "polldelay", M.utils.GETOPT_ARG.REQUIRED, "p" },
+        { "yieldtime", M.utils.GETOPT_ARG.REQUIRED, "t" },
         { "retry", M.utils.GETOPT_ARG.REQUIRED, "r" },
         { "retrywait", M.utils.GETOPT_ARG.REQUIRED, "w" },
         { "confirm", M.utils.GETOPT_ARG.REQUIRED, "c" },
@@ -2041,6 +2066,8 @@ function M.suricatta_funcs.server_start(defaults, argv, fconfig)
             end
         elseif opt == "p" then
             configuration.polldelay = tonumber(arg) or configuration.polldelay
+        elseif opt == "t" then
+            configuration.yieldtime = tonumber(arg) or configuration.yieldtime
         elseif opt == "r" then
             configuration.retries = tonumber(arg) or configuration.retries
         elseif opt == "w" then
@@ -2110,32 +2137,52 @@ function M.suricatta_funcs.server_start(defaults, argv, fconfig)
     end
 
     M.server.polldelay = configuration.polldelay
+    M.server.yieldtime.default = configuration.yieldtime or M.server.yieldtime.default
 
     M.channel.main = M.channel(M.utils.table.merge({
         -- An API Gateway may use this information to do steering.
-        headers_to_send = {
+        headers_to_send = M.utils.table.merge({
             ["X-Client-Version"] = M.device.version,
             ["X-Client-Id"] = M.device.id,
-        },
+        }, configuration.custom_http_headers)
     }, configuration))
     if not M.channel.main then
         suricatta.notify.error("Cannot initialize channel.")
         return suricatta.status.EINIT
     end
 
-    local url = ("%s/swagger.json"):format(M.channel.main.options.url)
-    suricatta.notify.debug("Suricatta querying %q", url)
-    repeat
-        local res, _, data = M.channel.main.get { url = url }
-        if not res then
-            suricatta.notify.warn(
-                "Got HTTP error code %d, sleeping %d seconds ...",
-                data.http_response_code,
-                M.channel.main.options.retry_sleep
-            )
-            suricatta.sleep(M.channel.main.options.retry_sleep)
+    repeat until (function()
+        --- @param  url string    URL to query for wfx OpenAPI Specification
+        --- @return boolean|nil   # `true` if specification was found and parsed successfully, `false` otherwise
+        local function fetch_json_schema(url)
+            suricatta.notify.debug("Querying wfx specification at %q", url)
+            local res, _, data = M.channel.main.get { url = url }
+            if res then
+                if data.http_response_code == 204 then -- HTTP error code 204 'No Content'
+                    local link = (data.received_headers['Link'] or ""):match("^<(http[s]*://[%w/%%%-_%.~:]+)>;")
+                    if link == nil then
+                        return false
+                    end
+                    suricatta.notify.debug("Got HTTP 204, following HTTP Header Link to %q", link)
+                    return fetch_json_schema(link)
+                end
+                return M.job.status:update_json_schema(((data or {}).json_reply or {}))
+            end
+            suricatta.notify.debug("Got HTTP error code %d", data.http_response_code)
         end
-    until res and M.job.status:update_json_schema(((data or {}).json_reply or {}))
+
+        for _, url in ipairs({
+            ("%s/swagger.json"):format(M.channel.main.options.url),
+            ("%s/openapi.json"):format(M.channel.main.options.url),
+        }) do
+            if fetch_json_schema(url) then
+                suricatta.notify.debug("Fetched and processed wfx specification.")
+                return true
+            end
+        end
+        suricatta.notify.warn("Couldn't get wfx specification, sleeping %d seconds ...", M.channel.main.options.retry_sleep)
+        suricatta.sleep(M.channel.main.options.retry_sleep)
+    end)()
 
     suricatta.notify.info("Running with device ID %q on %q", M.device.id, configuration.url)
     return suricatta.status.OK
@@ -2164,11 +2211,15 @@ suricatta.server.register(M.suricatta_funcs.server_stop, suricatta.server.SERVER
 --
 --- @return number  # Polling interval in seconds
 function M.suricatta_funcs.get_polling_interval()
-    -- Not implemented.
     -- Remotely setting the polling interval is the original concern of
     -- a device management solution that should set the polling interval
-    -- via SWUpdate IPC (or command line or configuration file).
-    return M.server.polldelay
+    -- via SWUpdate IPC (or command line or configuration file). The latter
+    -- can be done via a wfx workflow :)
+    --
+    -- While an update action is in progress, report the (likely short)
+    -- `yieldtime` as time between two polling intervals so not to wait
+    -- excessively long when a large (regular) polling interval is chosen.
+    return M.server.yieldtime.current or M.server.polldelay
 end
 suricatta.server.register(M.suricatta_funcs.get_polling_interval, suricatta.server.GET_POLLING_INTERVAL)
 
